summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/history
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-01-13 17:34:53 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-01-13 17:51:33 +0900
commit1329ec6abbcb7b79cd960e0ca138f16598d5f11f (patch)
tree8b64fab3a352aada6a046f69f1f7e8a6ad819594 /kopete/plugins/history
parent69c2eb8d5f2ed64c876b2a1081cc83ed9f4652d3 (diff)
downloadtdenetwork-1329ec6abbcb7b79cd960e0ca138f16598d5f11f.tar.gz
tdenetwork-1329ec6abbcb7b79cd960e0ca138f16598d5f11f.zip
Use new TQ_METHOD, TQ_SIGNAL, TQ_SLOT defines
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kopete/plugins/history')
-rw-r--r--kopete/plugins/history/historydialog.cpp42
-rw-r--r--kopete/plugins/history/historyguiclient.cpp6
-rw-r--r--kopete/plugins/history/historylogger.cpp6
-rw-r--r--kopete/plugins/history/historyplugin.cpp24
-rw-r--r--kopete/plugins/history/historypreferences.cpp14
5 files changed, 46 insertions, 46 deletions
diff --git a/kopete/plugins/history/historyguiclient.cpp b/kopete/plugins/history/historyguiclient.cpp
index aa2a97ee..b7b89e9c 100644
--- a/kopete/plugins/history/historyguiclient.cpp
+++ b/kopete/plugins/history/historyguiclient.cpp
@@ -41,9 +41,9 @@ HistoryGUIClient::HistoryGUIClient(Kopete::ChatSession *parent, const char *name
TQPtrList<Kopete::Contact> mb=m_manager->members();
m_logger=new HistoryLogger( mb.first() , this );
- actionLast=new TDEAction( i18n("History Last" ), TQString::fromLatin1( "go-last" ), 0, this, TQT_SLOT(slotLast()), actionCollection() , "historyLast" );
- actionPrev = KStdAction::back( this, TQT_SLOT(slotPrevious()), actionCollection() , "historyPrevious" );
- actionNext = KStdAction::forward( this, TQT_SLOT(slotNext()), actionCollection() , "historyNext" );
+ actionLast=new TDEAction( i18n("History Last" ), TQString::fromLatin1( "go-last" ), 0, this, TQ_SLOT(slotLast()), actionCollection() , "historyLast" );
+ actionPrev = KStdAction::back( this, TQ_SLOT(slotPrevious()), actionCollection() , "historyPrevious" );
+ actionNext = KStdAction::forward( this, TQ_SLOT(slotNext()), actionCollection() , "historyNext" );
// we are generally at last when begining
actionPrev->setEnabled(true);
diff --git a/kopete/plugins/history/historylogger.cpp b/kopete/plugins/history/historylogger.cpp
index 78bf25b2..c82ea7c5 100644
--- a/kopete/plugins/history/historylogger.cpp
+++ b/kopete/plugins/history/historylogger.cpp
@@ -49,7 +49,7 @@ HistoryLogger::HistoryLogger( Kopete::MetaContact *m, TQObject *parent, const c
m_oldSens=Default;
//the contact may be destroyed, for example, if the contact changes its metacontact
- connect(m_metaContact , TQT_SIGNAL(destroyed(TQObject *)) , this , TQT_SLOT(slotMCDeleted()));
+ connect(m_metaContact , TQ_SIGNAL(destroyed(TQObject *)) , this , TQ_SLOT(slotMCDeleted()));
setPositionToLast();
}
@@ -67,7 +67,7 @@ HistoryLogger::HistoryLogger( Kopete::Contact *c, TQObject *parent, const char
m_oldSens=Default;
//the contact may be destroyed, for example, if the contact changes its metacontact
- connect(m_metaContact , TQT_SIGNAL(destroyed(TQObject *)) , this , TQT_SLOT(slotMCDeleted()));
+ connect(m_metaContact , TQ_SIGNAL(destroyed(TQObject *)) , this , TQ_SLOT(slotMCDeleted()));
setPositionToLast();
}
@@ -292,7 +292,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
if(!m_saveTimer)
{
m_saveTimer=new TQTimer(this);
- connect( m_saveTimer, TQT_SIGNAL( timeout() ) , this, TQT_SLOT(saveToDisk()) );
+ connect( m_saveTimer, TQ_SIGNAL( timeout() ) , this, TQ_SLOT(saveToDisk()) );
}
if(!m_saveTimer->isActive())
m_saveTimer->start( m_saveTimerTime, true /*singleshot*/ );
diff --git a/kopete/plugins/history/historyplugin.cpp b/kopete/plugins/history/historyplugin.cpp
index fb48e79f..8404d38d 100644
--- a/kopete/plugins/history/historyplugin.cpp
+++ b/kopete/plugins/history/historyplugin.cpp
@@ -45,18 +45,18 @@ HistoryPlugin::HistoryPlugin( TQObject *parent, const char *name, const TQString
: Kopete::Plugin( HistoryPluginFactory::instance(), parent, name ), m_loggerFactory( this )
{
TDEAction *viewMetaContactHistory = new TDEAction( i18n("View &History" ),
- TQString::fromLatin1( "history" ), 0, this, TQT_SLOT(slotViewHistory()),
+ TQString::fromLatin1( "history" ), 0, this, TQ_SLOT(slotViewHistory()),
actionCollection(), "viewMetaContactHistory" );
viewMetaContactHistory->setEnabled(
Kopete::ContactList::self()->selectedMetaContacts().count() == 1 );
- connect(Kopete::ContactList::self(), TQT_SIGNAL(metaContactSelected(bool)),
- viewMetaContactHistory, TQT_SLOT(setEnabled(bool)));
+ connect(Kopete::ContactList::self(), TQ_SIGNAL(metaContactSelected(bool)),
+ viewMetaContactHistory, TQ_SLOT(setEnabled(bool)));
- connect(Kopete::ChatSessionManager::self(), TQT_SIGNAL(viewCreated(KopeteView*)),
- this, TQT_SLOT(slotViewCreated(KopeteView*)));
+ connect(Kopete::ChatSessionManager::self(), TQ_SIGNAL(viewCreated(KopeteView*)),
+ this, TQ_SLOT(slotViewCreated(KopeteView*)));
- connect(this, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(slotSettingsChanged()));
+ connect(this, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(slotSettingsChanged()));
setXMLFile("historyui.rc");
if(detectOldHistory())
@@ -79,8 +79,8 @@ HistoryPlugin::HistoryPlugin( TQObject *parent, const char *name, const TQString
if(!m_loggers.contains(*it))
{
m_loggers.insert(*it, new HistoryGUIClient( *it ) );
- connect( *it, TQT_SIGNAL(closing(Kopete::ChatSession*)),
- this, TQT_SLOT(slotKMMClosed(Kopete::ChatSession*)));
+ connect( *it, TQ_SIGNAL(closing(Kopete::ChatSession*)),
+ this, TQ_SLOT(slotKMMClosed(Kopete::ChatSession*)));
}
}
}
@@ -105,8 +105,8 @@ void HistoryPlugin::messageDisplayed(const Kopete::Message &m)
if(!m_loggers.contains(m.manager()))
{
m_loggers.insert(m.manager() , new HistoryGUIClient( m.manager() ) );
- connect(m.manager(), TQT_SIGNAL(closing(Kopete::ChatSession*)),
- this, TQT_SLOT(slotKMMClosed(Kopete::ChatSession*)));
+ connect(m.manager(), TQ_SIGNAL(closing(Kopete::ChatSession*)),
+ this, TQ_SLOT(slotKMMClosed(Kopete::ChatSession*)));
}
HistoryLogger *l=m_loggers[m.manager()]->logger();
@@ -152,8 +152,8 @@ void HistoryPlugin::slotViewCreated( KopeteView* v )
if(!m_loggers.contains(m_currentChatSession))
{
m_loggers.insert(m_currentChatSession , new HistoryGUIClient( m_currentChatSession ) );
- connect( m_currentChatSession, TQT_SIGNAL(closing(Kopete::ChatSession*)),
- this , TQT_SLOT(slotKMMClosed(Kopete::ChatSession*)));
+ connect( m_currentChatSession, TQ_SIGNAL(closing(Kopete::ChatSession*)),
+ this , TQ_SLOT(slotKMMClosed(Kopete::ChatSession*)));
}
if(!autoChatWindow || nbAutoChatWindow == 0)
diff --git a/kopete/plugins/history/historypreferences.cpp b/kopete/plugins/history/historypreferences.cpp
index b1bca2f6..52679290 100644
--- a/kopete/plugins/history/historypreferences.cpp
+++ b/kopete/plugins/history/historypreferences.cpp
@@ -36,13 +36,13 @@ HistoryPreferences::HistoryPreferences(TQWidget *parent, const char*/*name*/, co
(new TQVBoxLayout(this))->setAutoAdd(true);
p = new HistoryPrefsUI(this);
- connect(p->chkShowPrevious, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotShowPreviousChanged(bool)));
- connect(p->Number_Auto_chatwindow, TQT_SIGNAL(valueChanged(int)),
- this, TQT_SLOT(slotModified()));
- connect(p->Number_ChatWindow, TQT_SIGNAL(valueChanged(int)),
- this, TQT_SLOT(slotModified()));
- connect(p->History_color, TQT_SIGNAL(changed(const TQColor&)),
- this, TQT_SLOT(slotModified()));
+ connect(p->chkShowPrevious, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotShowPreviousChanged(bool)));
+ connect(p->Number_Auto_chatwindow, TQ_SIGNAL(valueChanged(int)),
+ this, TQ_SLOT(slotModified()));
+ connect(p->Number_ChatWindow, TQ_SIGNAL(valueChanged(int)),
+ this, TQ_SLOT(slotModified()));
+ connect(p->History_color, TQ_SIGNAL(changed(const TQColor&)),
+ this, TQ_SLOT(slotModified()));
load();
}
diff --git a/kopete/plugins/history/historydialog.cpp b/kopete/plugins/history/historydialog.cpp
index 01bff360..4842db32 100644
--- a/kopete/plugins/history/historydialog.cpp
+++ b/kopete/plugins/history/historydialog.cpp
@@ -102,7 +102,7 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
TQString fontStyle;
kdDebug(14310) << k_funcinfo << "called." << endl;
- setWFlags(TQt::WDestructiveClose); // send TQT_SIGNAL(closing()) on quit
+ setWFlags(TQt::WDestructiveClose); // send TQ_SIGNAL(closing()) on quit
// FIXME: Allow to show this dialog for only one contact
mMetaContact = mc;
@@ -161,21 +161,21 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
mHtmlPart->end();
- connect(mHtmlPart->browserExtension(), TQT_SIGNAL(openURLRequestDelayed(const KURL &, const KParts::URLArgs &)),
- this, TQT_SLOT(slotOpenURLRequest(const KURL &, const KParts::URLArgs &)));
- connect(mMainWidget->dateListView, TQT_SIGNAL(clicked(TQListViewItem*)), this, TQT_SLOT(dateSelected(TQListViewItem*)));
- connect(mMainWidget->searchButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSearch()));
- connect(mMainWidget->searchLine, TQT_SIGNAL(returnPressed()), this, TQT_SLOT(slotSearch()));
- connect(mMainWidget->searchLine, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotSearchTextChanged(const TQString&)));
- connect(mMainWidget->searchErase, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSearchErase()));
- connect(mMainWidget->contactComboBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotContactChanged(int)));
- connect(mMainWidget->messageFilterBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotFilterChanged(int )));
- connect(mHtmlPart, TQT_SIGNAL(popupMenu(const TQString &, const TQPoint &)), this, TQT_SLOT(slotRightClick(const TQString &, const TQPoint &)));
+ connect(mHtmlPart->browserExtension(), TQ_SIGNAL(openURLRequestDelayed(const KURL &, const KParts::URLArgs &)),
+ this, TQ_SLOT(slotOpenURLRequest(const KURL &, const KParts::URLArgs &)));
+ connect(mMainWidget->dateListView, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(dateSelected(TQListViewItem*)));
+ connect(mMainWidget->searchButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSearch()));
+ connect(mMainWidget->searchLine, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(slotSearch()));
+ connect(mMainWidget->searchLine, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotSearchTextChanged(const TQString&)));
+ connect(mMainWidget->searchErase, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSearchErase()));
+ connect(mMainWidget->contactComboBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotContactChanged(int)));
+ connect(mMainWidget->messageFilterBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotFilterChanged(int )));
+ connect(mHtmlPart, TQ_SIGNAL(popupMenu(const TQString &, const TQPoint &)), this, TQ_SLOT(slotRightClick(const TQString &, const TQPoint &)));
//initActions
TDEActionCollection* ac = new TDEActionCollection(this);
- mCopyAct = KStdAction::copy( this, TQT_SLOT(slotCopy()), ac );
- mCopyURLAct = new TDEAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "edit-copy" ), 0, this, TQT_SLOT( slotCopyURL() ), ac );
+ mCopyAct = KStdAction::copy( this, TQ_SLOT(slotCopy()), ac );
+ mCopyURLAct = new TDEAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "edit-copy" ), 0, this, TQ_SLOT( slotCopyURL() ), ac );
resize(650, 700);
centerOnScreen(this);
@@ -211,7 +211,7 @@ void HistoryDialog::init()
}
initProgressBar(i18n("Loading..."),mInit.dateMCList.count());
- TQTimer::singleShot(0,this,TQT_SLOT(slotLoadDays()));
+ TQTimer::singleShot(0,this,TQ_SLOT(slotLoadDays()));
}
void HistoryDialog::slotLoadDays()
@@ -219,7 +219,7 @@ void HistoryDialog::slotLoadDays()
if(mInit.dateMCList.isEmpty())
{
if (!mMainWidget->searchLine->text().isEmpty())
- TQTimer::singleShot(0, this, TQT_SLOT(slotSearch()));
+ TQTimer::singleShot(0, this, TQ_SLOT(slotSearch()));
doneProgressBar();
return;
}
@@ -235,7 +235,7 @@ void HistoryDialog::slotLoadDays()
new TDEListViewDateItem(mMainWidget->dateListView, c2Date, pair.metaContact());
}
mMainWidget->searchProgress->advance(1);
- TQTimer::singleShot(0,this,TQT_SLOT(slotLoadDays()));
+ TQTimer::singleShot(0,this,TQ_SLOT(slotLoadDays()));
}
@@ -586,7 +586,7 @@ void HistoryDialog::slotRightClick(const TQString &url, const TQPoint &point)
mCopyAct->setEnabled( mHtmlPart->hasSelection() );
mCopyAct->plug( chatWindowPopup );
- connect( chatWindowPopup, TQT_SIGNAL( aboutToHide() ), chatWindowPopup, TQT_SLOT( deleteLater() ) );
+ connect( chatWindowPopup, TQ_SIGNAL( aboutToHide() ), chatWindowPopup, TQ_SLOT( deleteLater() ) );
chatWindowPopup->popup(point);
}
@@ -596,18 +596,18 @@ void HistoryDialog::slotCopy()
qsSelection = mHtmlPart->selectedText();
if ( qsSelection.isEmpty() ) return;
- disconnect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
+ disconnect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), mHtmlPart, TQ_SLOT(slotClearSelection()));
TQApplication::clipboard()->setText(qsSelection, TQClipboard::Clipboard);
TQApplication::clipboard()->setText(qsSelection, TQClipboard::Selection);
- connect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
+ connect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), mHtmlPart, TQ_SLOT(slotClearSelection()));
}
void HistoryDialog::slotCopyURL()
{
- disconnect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
+ disconnect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), mHtmlPart, TQ_SLOT(slotClearSelection()));
TQApplication::clipboard()->setText( mURL, TQClipboard::Clipboard);
TQApplication::clipboard()->setText( mURL, TQClipboard::Selection);
- connect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
+ connect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), mHtmlPart, TQ_SLOT(slotClearSelection()));
}
#include "historydialog.moc"